#    AWSTrial, A mechanism and service for offering a cloud image trial
#
#    Copyright (C) 2010  Scott Moser <smoser@ubuntu.com>
#    Copyright (C) 2010  Dave Walker (Daviey) <DaveWalker@ubuntu.com>
#    Copyright (C) 2010  Michael Hall <mhall119@gmail.com>
#    Copyright (C) 2010  Dustin Kirkland <kirkland@ubuntu.com>
#    Copyright (C) 2010  Andreas Hasenack <andreas@canonical.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.http import HttpResponseRedirect
from trial.models import EmailBlacklist, UserProfile
from awstrial import settings

import DNS
import socket

def blacklisted_email_domain(email):
    if settings.USER_BLOCK_EMAIL_BLACKLIST:
      if email != u'':
        (user, domain) = email.split('@')
        if EmailBlacklist.objects.filter(domain=domain):
          return True
    return False

def client_using_tor(request):
    if settings.USER_BLOCK_TOR_GATEWAY:

      DNS.ParseResolvConf()
    
      client = ".".join(reversed(request.META['REMOTE_ADDR'].strip().split('.')))

      TARGET = ".".join(reversed(socket.gethostbyname(request.META['SERVER_NAME']).strip().split('.')))
      PORT = "443"
      TOR_SUBDOMAIN = "ip-port.exitlist.torproject.org"

      lookup = ("%s.%s.%s.%s") % (client,PORT,TARGET,TOR_SUBDOMAIN)
      request = DNS.DnsRequest(name=lookup,qtype='A')
      answer=request.req()

      if answer.header['status'] == "NOERROR":
        return True
    return False

def log_first_ip(request):
    if request.user.profile.initial_ip == None:
        user = request.user.profile 
        user.initial_ip = request.META['REMOTE_ADDR']
        user.save()

def safe_user_required(f):
        def wrap(request, *args, **kwargs):
                log_first_ip(request)
                if blacklisted_email_domain(request.user.email):
                        return HttpResponseRedirect("/account-problem/")
                if client_using_tor(request):
                        return HttpResponseRedirect("/account-problem/") 
                return f(request, *args, **kwargs)
        wrap.__doc__=f.__doc__
        wrap.__name__=f.__name__
        return wrap

