#    AWSTrial, A mechanism and service for offering a cloud image trial
#
#    Copyright (C) 2010  Scott Moser <smoser@ubuntu.com>
#    Copyright (C) 2010  Dave Walker (Daviey) <DaveWalker@ubuntu.com>
#    Copyright (C) 2010  Michael Hall <mhall119@gmail.com>
#    Copyright (C) 2010  Dustin Kirkland <kirkland@ubuntu.com>
#    Copyright (C) 2010  Andreas Hasenack <andreas@canonical.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from optparse import make_option
from django.core.management.base import BaseCommand, CommandError

from awstrial.trial.models import Instances
from awstrial.trial import ec2_helper
from awstrial.trial import util
from awstrial import settings
from datetime import timedelta

consolewait = timedelta(seconds=settings.CONSOLE_WAIT)

class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('--long', '-l', dest='long',
            help='Help for the long options'),
    )
    help = 'Poll to get console outputs'

    def handle(self, **options):
        # get list of instances in running that have empty console output
        # get list of instances
        #   for each instnace in running, without console output
        #      where > 4 minutes pass 'reservation' time
        #      get console output.
        #      if console output, save
        #   
        #   for each instance in terminated, without console output
        #      get console output, save
        for region in settings.REGION2AMI.keys():
            instances = Instances.objects.filter(region=region)
            conn = None

            for inst in instances:
                output=None
                if needsStartConsole(inst):
                    conn = getConn(region,conn)
                    output=ec2_helper.get_console_output(inst,region,conn)
                    inst.console_start=output
                    # i wonder if I should somehow refresh the instance here
                    # there could be race where another process writes
                    # after I've read, and then I save stale info
                    #print "saving console_start for %s" % inst.instance_id
                    inst.save()
                if needsTermConsole(inst):
                    if not output:
                        conn = getConn(region,conn)
                        output=ec2_helper.get_console_output(inst,region,conn)
                    #print "saving console_end for %s" % inst.instance_id
                    inst.console_end=output
                    inst.save()

def needsStartConsole(instance):
    # an instance should have its console collected if
    # it doesn't yet have console_start
    if instance.console_start: return False

    # it is > pending state
    if instance.status() == "pending": return False

    # the instance could have gone "straight to terminated" or
    # for some other reason not have a running time
    if not instance.running_time: return False

    # it has been at least a pre-defined time since it was found running
    if instance.running_time + consolewait > util.dtnow(): return False

    return True

def needsTermConsole(instance):
    # an instance should have its terminating console collected if
    # it doesn't yet have console_end
    if instance.console_end: return False

    # it is terminated
    if instance.status() != "terminated": return False
    return True

def getConn(region,conn=None):
    if not conn:
        return(ec2_helper.ec2_connection(region))
    return conn

# vi: ts=4 expandtab
