#    AWSTrial, A mechanism and service for offering a cloud image trial
#
#    Copyright (C) 2010  Scott Moser <smoser@ubuntu.com>
#    Copyright (C) 2010  Dave Walker (Daviey) <DaveWalker@ubuntu.com>
#    Copyright (C) 2010  Michael Hall <mhall119@gmail.com>
#    Copyright (C) 2010  Dustin Kirkland <kirkland@ubuntu.com>
#    Copyright (C) 2010  Andreas Hasenack <andreas@canonical.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.http import HttpResponse
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template.loader import render_to_string
from trial.models import Instances
from django.template import RequestContext, Context
from django import forms
from django.forms.widgets import *
from django.contrib.auth.decorators import login_required
from django.contrib.auth import logout
from django.shortcuts import get_object_or_404

from trial.models import Campaign, Instances, Feedback, User
from trial.forms import FeedbackForm


from awstrial.trial import ec2_helper, lp_helper, util
from awstrial.trial.auth import safe_user_required
from awstrial import settings



def index(request):
    """ Main landing Page """
    campaign = Campaign.objects.filter(active=True)

    context = {
        'campaign': campaign,
    }

    return render_to_response("index.html", context,
                              context_instance=RequestContext(request))

@login_required
@safe_user_required
def start(request,campaign):
    """ Check the auth'd user has an ssh key """
    user = request.user.profile
    user.has_ssh = lp_helper.has_sshkey(request.user)
    user.save()
 
    return HttpResponseRedirect("/%s/run/" % campaign)

@login_required
@safe_user_required
def run_instance(request,campaign):
    current_campaign=Campaign.objects.get(name=campaign)
    # First, check they haven't already used their instance.
    if not Instances.objects.filter(campaign__name=campaign,owner=request.user): 
        # Now Check the campaign is running and has avaliability left.
        if current_campaign.remaining() and (current_campaign.active):
            if request.method == "POST":
                # opt_marketing = opt in for marketing mail, bool
                user = request.user.profile
                user.opt_marketing = request.POST.get('opt_marketing', '')
                user.save()

                # a = disclaimer box
                a = request.POST.get('a', '')
                if a:
                    #try:
                    region = request.POST.get('region',None)
                    if region is not None:
                        regions = ( region, )
                    else:
                        regions = settings.REGIONS_TRY_ORDER
                    config = request.POST.get('config', '')
                    byobu = request.POST.get('byobu','')
                    set_password = request.POST.get('set_password',None)

                    password=None
                    if set_password:
                        password=util.rand_user_password()

                    ec2_helper.runit(campaign,lpid=request.user, regions=regions, config=config, byobu=byobu, password=password)

                    return HttpResponseRedirect("/%s/instance_info/" % campaign)

            # if the user did not have ssh keys, then the contacts.html
            # form will set a hidden form field indicating to set a password
            set_password = False
            if not request.user.profile.has_ssh:
                set_password = True
            return render_to_response('contacts.html',
                { 'form': Instances(), 'settings': settings,
                  'set_password': set_password },
                context_instance=RequestContext(request))

        else:
            return HttpResponseRedirect("/") # redirect to main page, campaign exceeded.
	
    #return render_to_response('contacts.html', {'form': Instances()},
    #			RequestContext(request))
    return HttpResponseRedirect("/%s/instance_info/" % campaign)

@login_required
@safe_user_required
def reserved_instance(request,campaign):
    """ Instance is now reserved """
    return render_to_response('thankyou.html', RequestContext(request))

@login_required
@safe_user_required
def info_instance(request,campaign):
    """ Return details about Instance """
    instance = Instances.objects.get(owner=request.user)
    instcfg = util.find_config(instance.config,settings.configs)
    context = {
        'instance': instance,
        'config': instcfg,
    }
    context['BASE_URL'] = settings.BASE_URL
    context['cloudconfig']=None
    if instcfg and instcfg['template']:
        context['cloudconfig']=render_to_string(instcfg['template'], { })

    return render_to_response('instance.html', context,
                              context_instance=RequestContext(request))

@login_required
@safe_user_required
def feedback(request):
    theUser = request.user
    try:
        instance = Feedback.objects.get(user=theUser)
    except Feedback.DoesNotExist:
        instance = Feedback(user=theUser)
    if request.method == 'POST': # If the form has been submitted...
        form = FeedbackForm(request.POST, instance = instance) # A form bound to the POST data
        if form.is_valid(): # All validation rules pass
            form.save()
            return render_to_response('thankyou.html',
                context_instance=RequestContext(request))
    else:
        form = FeedbackForm(instance = instance) # An unbound form

    templates = { 'form': form, 'user': request.user }
    return render_to_response('feedback.html', templates,
                              context_instance=RequestContext(request))

def logout_view(request):
    logout(request)
    return HttpResponseRedirect('/')

def nxs(request,username,instance_id):
    try:
        owner = User.objects.get(username=username)
    except User.DoesNotExist as e:
        return(HttpResponse("unknown\n"))

    try:
        instance = Instances.objects.get(instance_id=instance_id, owner=owner)
    except Instances.DoesNotExist as e:
        return(HttpResponse("unknown\n"))

    context = {
        'instance': instance,
        'iusername' : settings.USERNAME,
        }
    return render_to_response('nxs.html', context,
                              context_instance=RequestContext(request))

def istatus(request,username,instance_id,info):
    try:
        owner = User.objects.get(username=username)
    except User.DoesNotExist as e:
        return(HttpResponse("unknown\n"))

    try:
        instance = Instances.objects.get(instance_id=instance_id, owner=owner)
    except Instances.DoesNotExist as e:
        return(HttpResponse("unknown\n"))
    if info == "status":
        return(HttpResponse("%s\n" % instance.status()))
    return(HttpResponse("%s\n" % "unknown query"))


# vi: ts=4 expandtab
